@@ -14,12 +14,6 @@ class Node(object):
     def __str__(self):
         return self.delim.join(map(str, self.data))
 
-    def __repr__(self):
-        return '(%s%s)' % (
-                self.__class__.__name__,
-                ': %s' % ' '.join(map(repr, self.data)) if self.data else ''
-        )
-
     def parse(self, target):
         self.parent = target
 
@@ -76,7 +70,6 @@ class ContentNode(ParseNode):
                     key=lambda x: SORTING.get(x.name, 999 ))
 
         nl, ws, ts = self.root.cache['delims']
-        semicolon = '' if self.root.cache['opts'].get('compress') else ';'
 
         return ''.join((
 
@@ -88,11 +81,9 @@ class ContentNode(ParseNode):
 
                 "%s{%s%s" % (ws, nl, ts) if self.name else '',
 
-                # Declarations
+                #Declarations
                 (';%s%s' % ( nl, ts )).join(str(d) for d in self.declareset),
 
-                semicolon,
-
                 '}%s%s' % ( nl, nl ) if self.name else ''
 
             )) if self.declareset else '',
