@@ -1,12 +1,12 @@
 import unittest
 
-from scss.parser import Stylecheet
+from scss.parser import Stylesheet
 
 
 class TestSCSS( unittest.TestCase ):
 
     def setUp(self):
-        self.parser = Stylecheet()
+        self.parser = Stylesheet()
 
     def test_font_face(self):
         src = """
@@ -17,7 +17,7 @@ class TestSCSS( unittest.TestCase ):
                     url('minion-webfont.ttf') format('truetype');
                     font-weight: normal;
                     font-style: normal;
-                    font-size: 100% * ( 12px / 16px );
+                    font-size: ( 12px / 16px ) * 100%;
             }
 
             @font-face {
@@ -34,7 +34,6 @@ class TestSCSS( unittest.TestCase ):
                     font-family: 'MyMinionPro';
             }
         """
-        test = "@font-face {\n\tfont-family: 'MyMinionPro';\n\tfont-size: .75px;\n\tfont-style: normal;\n\tfont-weight: normal;\n\tsrc: url('minion-webfont.eot?') format('eot'), url('minion-webfont.woff') format('woff'), url('minion-webfont.ttf') format('truetype')}\n\n@font-face {\n\tfont-family: 'MyMinionProItalic';\n\tfont-style: italic;\n\tfont-weight: normal;\n\tsrc: url('minionpro-it-webfont.eot?') format('eot'), url('minionpro-it-webfont.woff') format('woff'), url('minionpro-it-webfont.ttf') format('truetype')}\n\nh1, h2, h3, time, ol#using .number {\n\tfont-weight: normal;\n\tfont-family: 'MyMinionPro'}"
-        out = self.parser.parse(src)
+        test = "@font-face {\n\tfont-weight: normal;\n\tfont-style: normal;\n\tfont-size: 75%;\n\tfont-family: 'MyMinionPro';\n\tsrc: url('minion-webfont.eot?') format('eot') , url('minion-webfont.woff') format('woff') , url('minion-webfont.ttf') format('truetype')}\n\n@font-face {\n\tfont-weight: normal;\n\tfont-style: italic;\n\tfont-family: 'MyMinionProItalic';\n\tsrc: url('minionpro-it-webfont.eot?') format('eot') , url('minionpro-it-webfont.woff') format('woff') , url('minionpro-it-webfont.ttf') format('truetype')}\n\nh1, h2, h3, time, ol#using .number {\n\tfont-weight: normal;\n\tfont-family: 'MyMinionPro'}\n\n"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
-
