@@ -6,7 +6,7 @@ from scss.parser import Stylesheet
 class TestSCSS( unittest.TestCase ):
 
     def setUp(self):
-        self.parser = Stylesheet(options=dict(compress=True))
+        self.parser = Stylesheet()
 
     def test_for(self):
         src = """
@@ -27,6 +27,6 @@ class TestSCSS( unittest.TestCase ):
                     color: red; }
             }
         """
-        test = ".test{color:#00f}.test .span-1{width:6px}.test .span-2{width:7px}.test .span-3{width:8px}.test .span-4{width:9px}.span-1{color:#f00}.span-2{color:#f00}"
+        test = ".test {\n\tcolor: #00f}\n\n.test .span-1 {\n\twidth: 6px}\n\n.test .span-2 {\n\twidth: 7px}\n\n.test .span-3 {\n\twidth: 8px}\n\n.test .span-4 {\n\twidth: 9px}\n\n.span-1 {\n\tcolor: #f00}\n\n.span-2 {\n\tcolor: #f00}\n\n"
         out = self.parser.loads(src)
         self.assertEqual(test, out)
