@@ -126,8 +126,8 @@ The location of the generated CSS can be set using a colon:
             ttime = os.path.getmtime(infile)
             if mtime < ttime:
                 print " Parse '%s' to '%s' .. done" % ( infile, outfile )
-                out = s.load(open(infile, 'r'))
-                open(outfile, 'w').write(out)
+                s.load(open(infile, 'r'))
+                open(outfile, 'w').write(str(s))
                 f[2] = os.path.getmtime(outfile)
 
         print 'SCSS v. %s watch mode' % VERSION
